@@ -1,15 +1,23 @@
-# -*- coding: utf-8 -*-
+#!/usr/local/bin python
+# encoding: utf-8
 
-from blueflask.flask_api import app
+from blueflask.flask_api import FlaskApp
 
 from .v1 import api
 from .v1 import __version__
-from ..consts import API_REGISTRY
+
+from ..consts import ADDRESS
+from ..consts import APIGW
 from ..consts import LOGS
 from ..consts import HOSTNAME
 from ..consts import SERVICE_CODE
 
+import requests
 
+flask_app = FlaskApp(SERVICE_CODE)
+flask_app.produce_handlers_and_documentation()
+
+app = flask_app.app
 app.config['LOGGER_NAME'] = 'hlr-services-api'
 app.config['TITLE'] = 'API HLR'
 app.config['DESCRIPTION'] = "Communications Telnet avec le HLR"
@@ -17,14 +25,19 @@ app.config['VERSION'] = __version__
 app.logger.handlers = LOGS.logger.handlers
 app.register_blueprint(api)
 
-
-API_REGISTRY.hmset(
-    'service:hlr-services',
-    {
+requests.post(
+    'https://{fqdn}/registry'.format(fqdn=APIGW),
+    json={
+        'service': 'hlr',
+        'version': int(eval(__version__)),
+        'address': ADDRESS,
         'service_code': SERVICE_CODE,
         'host': HOSTNAME,
         'status': 'up'
         }
     )
 
+if __name__ == '__main__':
+    app.run(debug=True)
+
 # EOF
