@@ -2,13 +2,17 @@
 
 from flask import request
 
-from blueflask.lib.infos import created, success
-from blueflask.lib.errors import conflict, internal_error, not_found
+from blueflask.lib.infos import success
+from blueflask.lib.errors import internal_error, not_found
 
 from ...consts import SERVICE_CODE
 from ...core import Client
 from . import api
 
+import pika
+
+import json
+
 
 @api.route('/subscribers/imsi/<string:isdn>', methods=['GET'])
 def list_imsi(isdn):
@@ -290,46 +294,49 @@ def create_subscriber():
             status:
               type: string
     """
-    client = Client()
+    auth = request.authorization
+    if auth:
+        auth = (auth.username, auth.password)
     data = request.get_json()
-    imsi = data['imsi']
-    isdn = data['isdn']
-    client.add_subscriber(imsi, isdn)
-    code = client.response['code']
-    message = client.response['message']
-    return_code = '{service_code}-{code}'.format(
-        service_code=SERVICE_CODE,
-        code=code
-        )
-    if code:
-        if code == 3002:
-            return conflict(
-                message=message,
-                code=return_code,
-                service_code=SERVICE_CODE
+    params = request.args or {}
+    headers = request.headers or {}
+    document = {
+        'auth': auth or (),
+        'params': params,
+        'headers': headers,
+        'json': data
+        }
+    try:
+        connection = pika.BlockingConnection(
+            pika.ConnectionParameters(
+                host='localhost',
+                virtual_host='/hlr'
                 )
-        else:
-            return internal_error(
-                message=message,
-                code=return_code,
-                service_code=SERVICE_CODE
-                )
-    else:
-        client.update_gprs_profile(imsi, True)
-        code = client.response['code']
-        message = client.response['message']
-        return_code = '{service_code}-{code}'.format(
-            service_code=SERVICE_CODE,
-            code=code
             )
-        if code:
-            return internal_error(
-                message=message,
-                code=return_code,
-                service_code=SERVICE_CODE
-                )
-        else:
-            return created(service_code=SERVICE_CODE)
+    except Exception:
+        # exception de connection lancée par pika
+        # il faut que rabbitmq-server soit installé
+        # et que le vhost /{service} existe déjà
+        return internal_error(
+            message="serveur RabbitMQ injoignable",
+            code='{}-5000'.format(SERVICE_CODE),
+            service_code=SERVICE_CODE
+            )
+    else:
+        channel = connection.channel()
+        channel.exchange_declare(
+            exchange='sendcmd',
+            exchange_type='topic'
+            )
+        # déclaration idempotente: pas grave si l'exchange existe déjà
+        channel.basic_publish(
+            exchange='sendcmd',
+            routing_key='create_subscriber',
+            body=json.dumps(document),
+            properties=pika.BasicProperties(delivery_mode=2)
+            )
+        connection.close()
+        return success(service_code=SERVICE_CODE)
 
 
 @api.route('/subscribers', methods=['DELETE'])
